@@ -1,10 +1,18 @@
+from typing import Any, Dict, Optional
+
 from vellum.workflows.errors import WorkflowError, WorkflowErrorCode
 
 
 class NodeException(Exception):
-    def __init__(self, message: str, code: WorkflowErrorCode = WorkflowErrorCode.INTERNAL_ERROR):
+    def __init__(
+        self,
+        message: str,
+        code: WorkflowErrorCode = WorkflowErrorCode.INTERNAL_ERROR,
+        raw_data: Optional[Dict[str, Any]] = None,
+    ):
         self.message = message
         self.code = code
+        self.raw_data = raw_data
         super().__init__(message)
 
     @property
@@ -12,11 +20,12 @@ class NodeException(Exception):
         return WorkflowError(
             message=self.message,
             code=self.code,
+            raw_data=self.raw_data,
         )
 
     @staticmethod
     def of(workflow_error: WorkflowError) -> "NodeException":
-        return NodeException(message=workflow_error.message, code=workflow_error.code)
+        return NodeException(message=workflow_error.message, code=workflow_error.code, raw_data=workflow_error.raw_data)
 
 
 class WorkflowInitializationException(Exception):
